@@ -83,6 +83,7 @@ nlminbControl <- function(eval.max=200,
                           diff.g=NULL,
                           rxControl=NULL,
                           optExpression=TRUE, sumProd=FALSE,
+                          literalFix=TRUE,
                           returnNlminb=FALSE,
                           solveType=c("hessian", "grad", "fun"),
 
@@ -115,7 +116,6 @@ nlminbControl <- function(eval.max=200,
                           adjObf=TRUE, ci=0.95, sigdig=4, sigdigTable=NULL, ...) {
   checkmate::assertIntegerish(eval.max, len=1, any.missing=FALSE, lower=1)
   checkmate::assertIntegerish(iter.max, len=1, any.missing=FALSE, lower=1)
-  checkmate::assertIntegerish(print, len=1, any.missing=FALSE, lower=1)
   checkmate::assertIntegerish(trace, len=1, any.missing=FALSE, lower=0)
   checkmate::assertNumeric(rel.tol, len=1, any.missing=FALSE, lower=0)
   checkmate::assertNumeric(x.tol, len=1, any.missing=FALSE, lower=0)
@@ -123,6 +123,7 @@ nlminbControl <- function(eval.max=200,
   checkmate::assertNumeric(step.min, len=1, any.missing=FALSE, lower=0)
   checkmate::assertNumeric(step.max, len=1, any.missing=FALSE, lower=0)
   checkmate::assertLogical(optExpression, len=1, any.missing=FALSE)
+  checkmate::assertLogical(literalFix, len=1, any.missing=FALSE)
   checkmate::assertLogical(sumProd, len=1, any.missing=FALSE)
   checkmate::assertLogical(returnNlminb, len=1, any.missing=FALSE)
   checkmate::assertLogical(calcTables, len=1, any.missing=FALSE)
@@ -273,6 +274,7 @@ nlminbControl <- function(eval.max=200,
 
                covMethod=covMethod,
                optExpression=optExpression,
+               literalFix=literalFix,
                sumProd=sumProd,
                rxControl=rxControl,
                returnNlminb=returnNlminb, addProp=addProp, calcTables=calcTables,
@@ -451,9 +453,9 @@ getValidNlmixrCtl.nlminb <- function(control) {
   setNames(vapply(seq_along(.iniDf$name),
                   function(i) {
                     if (.iniDf$fix[i]) {
-                      return(.iniDf$est[i])
+                      .iniDf$est[i]
                     } else {
-                      return(nlm$par[.iniDf$name[i]])
+                      nlm$par[.iniDf$name[i]]
                     }
                   }, double(1), USE.NAMES=FALSE),
            .iniDf$name)
@@ -467,6 +469,7 @@ getValidNlmixrCtl.nlminb <- function(control) {
                                 covMethod=0L,
                                 sumProd=.nlminbControl$sumProd,
                                 optExpression=.nlminbControl$optExpression,
+                                literalFix=.nlminbControl$literalFix,
                                 scaleTo=0,
                                 calcTables=.nlminbControl$calcTables,
                                 addProp=.nlminbControl$addProp,
