@@ -168,6 +168,28 @@ nlmixr <- nlmixr2
   assignInMyNamespace(".finalUiCompressed", TRUE)
   rxode2::rxSetCovariateNamesForPiping(NULL)
 }
+#' Infer missing estimation routine
+#'
+#' @param env prep environment for nlmixr2
+#' @param est estimation routine, could actually be a control
+#' @return actual estimation routine (could be inferred)
+#' @noRd
+#' @author Matthew L. Fidler
+.nlmixr2inferEst <- function(env, est) {
+  if (!env$missingEst) {
+    .cls <- class(est)
+    if (grepl("^.*?Control$", .cls)) {
+      .est <- sub("^(.*?)Control$", "\\1", .cls)
+      if (env$missingControl) {
+        env$control <- getValidNlmixrControl(est, .est)
+        est <- .est
+        .minfo(paste0("infer estimation {.code ", est, "} from control"))
+        env$missingControl <- FALSE
+      }
+    }
+  }
+  est
+}
 
 #' @rdname nlmixr2
 #' @export
@@ -191,7 +213,7 @@ nlmixr2.function <- function(object, data=NULL, est = NULL, control = NULL, tabl
     return(.uif)
   }
   .env <- new.env(parent=emptyenv())
-  .env$ui <- .nlmixrPreprocessUi(.uif)
+  .env$ui <- .nlmixrPreprocessUi(.uif, control)
   if (is.null(data) && !is.null(.nlmixr2pipeData)) {
     .env$data <- .nlmixr2pipeData
     .minfo("use {.code data} from pipeline")
@@ -200,6 +222,12 @@ nlmixr2.function <- function(object, data=NULL, est = NULL, control = NULL, tabl
   } else {
     .env$data <- data
   }
+  .env$missingTable <- missing(table)
+  .env$missingControl <- missing(control)
+  .env$missingEst <- missing(est)
+  .env$control <- control
+  est <- .nlmixr2inferEst(.env, est)
+  control <- .env$control
   if (is.null(control) && !is.null(.nlmixr2pipeControl)) {
     .minfo("use {.code control} from pipeline")
     .env$control <- getValidNlmixrControl(.nlmixr2pipeControl, est)
@@ -216,9 +244,6 @@ nlmixr2.function <- function(object, data=NULL, est = NULL, control = NULL, tabl
     .minfo("use {.code est} from pipeline")
     est <- .nlmixr2pipeEst
   }
-  .env$missingTable <- missing(table)
-  .env$missingControl <- missing(control)
-  .env$missingEst <- missing(est)
   class(.env) <- c(est, "nlmixr2Est")
   nlmixr2Est0(.env)
 }
@@ -237,7 +262,7 @@ nlmixr2.rxUi <- function(object, data=NULL, est = NULL, control = NULL, table =
     return(.uif)
   }
   .env <- new.env(parent=emptyenv())
-  .env$ui <- .nlmixrPreprocessUi(.uif)
+  .env$ui <- .nlmixrPreprocessUi(.uif, control)
   .missingData <- FALSE
   if (is.null(data)) {
     data <- NULL
@@ -253,6 +278,12 @@ nlmixr2.rxUi <- function(object, data=NULL, est = NULL, control = NULL, table =
   } else {
     .env$data <- data
   }
+  .env$missingTable <- missing(table)
+  .env$missingControl <- missing(control)
+  .env$missingEst <- missing(est)
+  .env$control <- control
+  est <- .nlmixr2inferEst(.env, est)
+  control <- .env$control
   if (is.null(control) && !is.null(.nlmixr2pipeControl)) {
     .env$control <- getValidNlmixrControl(.nlmixr2pipeControl, est)
     .minfo("use {.code control} from pipeline")
@@ -295,9 +326,6 @@ nlmixr2.rxUi <- function(object, data=NULL, est = NULL, control = NULL, table =
     est <- .nlmixr2pipeEst
     .minfo("use {.code est} from pipeline")
   }
-  .env$missingTable <- missing(table)
-  .env$missingControl <- missing(control)
-  .env$missingEst <- missing(est)
   class(.env) <- c(est, "nlmixr2Est")
   nlmixr2Est0(.env)
 }
@@ -319,20 +347,29 @@ nlmixr2.nlmixr2FitCore <- function(object, data=NULL, est = NULL, control = NULL
     .minfo("use {.code data} from pipeline")
   }  else if (missing(data)) {
     data <- object$origData
-    .minfo("use {.code data} from prior fit")
+   .minfo("use {.code data} from prior/supplied fit")
   }
   if (is.null(est) && !is.null(.nlmixr2pipeEst)) {
     est <- .nlmixr2pipeEst
     .minfo("use {.code est} from pipeline")
   } else if (missing(est)) {
-    .minfo("use {.code est} from prior fit")
+    .minfo("use {.code est} from prior/supplied fit")
     est <- object$est
   }
+  .env <- new.env(parent=emptyenv())
+  .env$control <- control
+  if (!is.null(est)) {
+    .env$missingEst <- FALSE
+  } else {
+    .env$missingEst <- missing(est)
+  }
+  est <- .nlmixr2inferEst(.env, est)
+  control <- .env$control
   if (is.null(control) && !is.null(.nlmixr2pipeControl)) {
     .minfo("use {.code control} from pipeline")
     control <- getValidNlmixrControl(.nlmixr2pipeControl, est)
   } else if (is.null(control)) {
-    .minfo("use {.code control} from prior fit")
+    .minfo("use/adapt {.code control} from prior/supplied fit")
     control <- getValidNlmixrControl(object$control, est)
   } else {
     control <- getValidNlmixrControl(control, est)
@@ -341,17 +378,20 @@ nlmixr2.nlmixr2FitCore <- function(object, data=NULL, est = NULL, control = NULL
     table <- getValidNlmixrControl(.nlmixr2pipeTable, "tableControl")
     .minfo("use {.code table} from pipeline")
   } else if (is.null(table)) {
-    .minfo("use {.code table} from prior fit")
+    .minfo("use {.code table} from prior/supplied fit")
     table <- getValidNlmixrControl(object$table, "tableControl")
   } else {
     table <- getValidNlmixrControl(table, "tableControl")
   }
-  .env <- new.env(parent=emptyenv())
   .ui <- rxode2::rxUiDecompress(object$ui)
-  .env$ui <- .nlmixrPreprocessUi(.ui)
+  .env$ui <- .nlmixrPreprocessUi(.ui, control)
   .env$data <- data
   .env$control <- control
   .env$table <- table
+  .env$control <- control
+  .env$missingEst <- missing(est)
+  est <- .nlmixr2inferEst(.env, est)
+  control <- .env$control
   class(.env) <- c(est, "nlmixr2Est")
   nlmixr2Est0(.env)
 }
