@@ -88,6 +88,7 @@ nlsControl <- function(maxiter=10000,
                        trace = FALSE, #nolint
                        rxControl=NULL,
                        optExpression=TRUE, sumProd=FALSE,
+                       literalFix=TRUE,
                        returnNls=FALSE,
                        addProp = c("combined2", "combined1"),
                        calcTables=TRUE, compress=TRUE,
@@ -130,6 +131,7 @@ nlsControl <- function(maxiter=10000,
   checkmate::assertNumeric(tol, len=1, any.missing=FALSE, lower=0)
   checkmate::assertNumeric(minFactor, len=1, any.missing=FALSE, lower=0)
   checkmate::assertLogical(optExpression, len=1, any.missing=FALSE)
+  checkmate::assertLogical(literalFix, len=1, any.missing=FALSE)
   checkmate::assertLogical(sumProd, len=1, any.missing=FALSE)
   checkmate::assertLogical(returnNls, len=1, any.missing=FALSE)
   checkmate::assertLogical(calcTables, len=1, any.missing=FALSE)
@@ -233,6 +235,7 @@ nlsControl <- function(maxiter=10000,
                gradTo=gradTo,
 
                optExpression=optExpression,
+               literalFix=literalFix,
                sumProd=sumProd,
                rxControl=rxControl,
                returnNls=returnNls,
@@ -621,7 +624,7 @@ rxUiGet.nlsHdTheta <- function(x, ...) {
       .all.zero <<- FALSE
     }
     rxode2::rxTick()
-    return(.ret)
+    .ret
   })
   if (.all.zero) {
     stop("none of the predictions depend on 'THETA'", call. = FALSE)
@@ -941,11 +944,11 @@ rxUiGet.nlsFormula <- function(x, ..., grad=FALSE) {
   }
   setNames(vapply(seq_along(.iniDf$ntheta), function(t) {
     if (.iniDf$err[t] %in% c("add", "prop", "pow")) {
-      return(.sd)
+      .sd
     } else if (.iniDf$fix[t]) {
-      return(.iniDf$est[t])
+      .iniDf$est[t]
     } else {
-      return(.theta0[.iniDf$name[t]])
+      .theta0[.iniDf$name[t]]
     }
   }, double(1), USE.NAMES=FALSE), .iniDf$name)
 }
@@ -959,6 +962,7 @@ rxUiGet.nlsFormula <- function(x, ..., grad=FALSE) {
                                 covMethod=0L,
                                 sumProd=.nlsControl$sumProd,
                                 optExpression=.nlsControl$optExpression,
+                                literalFix=.nlsControl$literalFix,
                                 scaleTo=0,
                                 calcTables=.nlsControl$calcTables,
                                 addProp=.nlsControl$addProp,
